aboutsummaryrefslogtreecommitdiffstats
path: root/plugins/reception-plugins/src/main/java/org/onap
diff options
context:
space:
mode:
authorRam Krishna Verma <ram_krishna.verma@bell.ca>2020-03-02 15:27:21 -0500
committerRam Krishna Verma <ram_krishna.verma@bell.ca>2020-03-03 09:42:51 -0500
commitccc3e28512988345e640097381d2ae0be46fe986 (patch)
treee80d52e8d27c1492df9807e94296d79ce567fa1c /plugins/reception-plugins/src/main/java/org/onap
parent7b63879e6837a0242ca0d68540830031c55b4ed6 (diff)
Remove policy/engine & apex dependency from distribution
Issue-ID: POLICY-2404 Change-Id: Ia3084c55ea65a3119354079d9afd3ee35689b7d4 Signed-off-by: Ram Krishna Verma <ram_krishna.verma@bell.ca>
Diffstat (limited to 'plugins/reception-plugins/src/main/java/org/onap')
-rw-r--r--plugins/reception-plugins/src/main/java/org/onap/policy/distribution/reception/decoding/hpa/Attribute.java (renamed from plugins/reception-plugins/src/main/java/org/onap/policy/distribution/reception/decoding/pdpx/Attribute.java)2
-rw-r--r--plugins/reception-plugins/src/main/java/org/onap/policy/distribution/reception/decoding/hpa/Content.java (renamed from plugins/reception-plugins/src/main/java/org/onap/policy/distribution/reception/decoding/pdpx/Content.java)2
-rw-r--r--plugins/reception-plugins/src/main/java/org/onap/policy/distribution/reception/decoding/hpa/Directive.java (renamed from plugins/reception-plugins/src/main/java/org/onap/policy/distribution/reception/decoding/pdpx/Directive.java)2
-rw-r--r--plugins/reception-plugins/src/main/java/org/onap/policy/distribution/reception/decoding/hpa/ExtractFromNode.java (renamed from plugins/reception-plugins/src/main/java/org/onap/policy/distribution/reception/decoding/pdpx/ExtractFromNode.java)72
-rw-r--r--plugins/reception-plugins/src/main/java/org/onap/policy/distribution/reception/decoding/hpa/FlavorFeature.java (renamed from plugins/reception-plugins/src/main/java/org/onap/policy/distribution/reception/decoding/pdpx/FlavorFeature.java)2
-rw-r--r--plugins/reception-plugins/src/main/java/org/onap/policy/distribution/reception/decoding/hpa/FlavorProperty.java (renamed from plugins/reception-plugins/src/main/java/org/onap/policy/distribution/reception/decoding/pdpx/FlavorProperty.java)2
-rw-r--r--plugins/reception-plugins/src/main/java/org/onap/policy/distribution/reception/decoding/hpa/HpaFeatureAttribute.java (renamed from plugins/reception-plugins/src/main/java/org/onap/policy/distribution/reception/decoding/pdpx/HpaFeatureAttribute.java)2
-rw-r--r--plugins/reception-plugins/src/main/java/org/onap/policy/distribution/reception/decoding/hpa/PolicyDecoderCsarHpa.java (renamed from plugins/reception-plugins/src/main/java/org/onap/policy/distribution/reception/decoding/pdpx/PolicyDecoderCsarPdpxLifecycleApi.java)18
-rw-r--r--plugins/reception-plugins/src/main/java/org/onap/policy/distribution/reception/decoding/hpa/PolicyDecoderCsarHpaParameters.java (renamed from plugins/reception-plugins/src/main/java/org/onap/policy/distribution/reception/decoding/pdpx/PolicyDecoderCsarPdpxLifecycleApiParameters.java)10
-rw-r--r--plugins/reception-plugins/src/main/java/org/onap/policy/distribution/reception/decoding/pdpx/ConfigBody.java115
-rw-r--r--plugins/reception-plugins/src/main/java/org/onap/policy/distribution/reception/decoding/pdpx/PdpxPolicy.java127
-rw-r--r--plugins/reception-plugins/src/main/java/org/onap/policy/distribution/reception/decoding/pdpx/PolicyDecoderCsarPdpx.java122
-rw-r--r--plugins/reception-plugins/src/main/java/org/onap/policy/distribution/reception/decoding/pdpx/PolicyDecoderCsarPdpxConfigurationParameterGroup.java49
13 files changed, 54 insertions, 471 deletions
diff --git a/plugins/reception-plugins/src/main/java/org/onap/policy/distribution/reception/decoding/pdpx/Attribute.java b/plugins/reception-plugins/src/main/java/org/onap/policy/distribution/reception/decoding/hpa/Attribute.java
index 9962894e..37f79f6b 100644
--- a/plugins/reception-plugins/src/main/java/org/onap/policy/distribution/reception/decoding/pdpx/Attribute.java
+++ b/plugins/reception-plugins/src/main/java/org/onap/policy/distribution/reception/decoding/hpa/Attribute.java
@@ -18,7 +18,7 @@
* ============LICENSE_END=========================================================
*/
-package org.onap.policy.distribution.reception.decoding.pdpx;
+package org.onap.policy.distribution.reception.decoding.hpa;
import com.google.gson.annotations.SerializedName;
diff --git a/plugins/reception-plugins/src/main/java/org/onap/policy/distribution/reception/decoding/pdpx/Content.java b/plugins/reception-plugins/src/main/java/org/onap/policy/distribution/reception/decoding/hpa/Content.java
index ef4584cb..a6e70bd9 100644
--- a/plugins/reception-plugins/src/main/java/org/onap/policy/distribution/reception/decoding/pdpx/Content.java
+++ b/plugins/reception-plugins/src/main/java/org/onap/policy/distribution/reception/decoding/hpa/Content.java
@@ -18,7 +18,7 @@
* ============LICENSE_END=========================================================
*/
-package org.onap.policy.distribution.reception.decoding.pdpx;
+package org.onap.policy.distribution.reception.decoding.hpa;
import java.util.ArrayList;
import java.util.List;
diff --git a/plugins/reception-plugins/src/main/java/org/onap/policy/distribution/reception/decoding/pdpx/Directive.java b/plugins/reception-plugins/src/main/java/org/onap/policy/distribution/reception/decoding/hpa/Directive.java
index 6df5bc38..87889cc1 100644
--- a/plugins/reception-plugins/src/main/java/org/onap/policy/distribution/reception/decoding/pdpx/Directive.java
+++ b/plugins/reception-plugins/src/main/java/org/onap/policy/distribution/reception/decoding/hpa/Directive.java
@@ -18,7 +18,7 @@
* ============LICENSE_END=========================================================
*/
-package org.onap.policy.distribution.reception.decoding.pdpx;
+package org.onap.policy.distribution.reception.decoding.hpa;
import java.util.ArrayList;
import java.util.List;
diff --git a/plugins/reception-plugins/src/main/java/org/onap/policy/distribution/reception/decoding/pdpx/ExtractFromNode.java b/plugins/reception-plugins/src/main/java/org/onap/policy/distribution/reception/decoding/hpa/ExtractFromNode.java
index a7313876..0406020c 100644
--- a/plugins/reception-plugins/src/main/java/org/onap/policy/distribution/reception/decoding/pdpx/ExtractFromNode.java
+++ b/plugins/reception-plugins/src/main/java/org/onap/policy/distribution/reception/decoding/hpa/ExtractFromNode.java
@@ -19,7 +19,7 @@
* ============LICENSE_END=========================================================
*/
-package org.onap.policy.distribution.reception.decoding.pdpx;
+package org.onap.policy.distribution.reception.decoding.hpa;
import com.google.common.collect.ImmutableMap;
import com.google.gson.Gson;
@@ -61,13 +61,13 @@ public class ExtractFromNode {
private static final String CPU_ARCHITECTURE_PATH = "virtual_cpu#cpu_architecture";
private static final String MEMORY_PAGE_SIZE_PATH = "virtual_memory#vdu_mem_requirements#memoryPageSize";
private static final String NETWORK_INTERFACE_TYPE_PATH =
- "virtual_network_interface_requirements#network_interface_requirements#interfaceType";
+ "virtual_network_interface_requirements#network_interface_requirements#interfaceType";
private static final String NETWORK_PCI_PATH =
- "virtual_network_interface_requirements#nic_io_requirements#logical_node_requirements";
+ "virtual_network_interface_requirements#nic_io_requirements#logical_node_requirements";
private static final String BASIC_CAPABILITIES_HPA_FEATURE = "basicCapabilities";
private static final String HUGE_PAGES_HPA_FEATURE = "hugePages";
private static final Map<String, String> NETWORK_HPA_FEATURE_MAP =
- ImmutableMap.of("SR-IOV", "sriovNICNetwork", "PCI-Passthrough", "pciePassthrough");
+ ImmutableMap.of("SR-IOV", "sriovNICNetwork", "PCI-Passthrough", "pciePassthrough");
private static final Pattern PATTERN = Pattern.compile("(\\D*)(\\d+)(\\D*)");
private ISdcCsarHelper sdcCsarHelper;
final Gson gson = new GsonBuilder().serializeNulls().setPrettyPrinting().disableHtmlEscaping().create();
@@ -77,8 +77,8 @@ public class ExtractFromNode {
}
/**
- * ExtractInfo from VNF , each VNF may includes more than one VDUs and CPs return new generated PdpxPolicy if it has
- * got Hpa feature info or else return null.
+ * ExtractInfo from VNF , each VNF may includes more than one VDUs and CPs return new
+ * generated OptimizationPolicy if it has got Hpa feature info or else return null.
*
* @param node the NodeTemplate
*
@@ -124,7 +124,8 @@ public class ExtractFromNode {
/**
- * ExtractInfofromVdu, supported hpa features, All under the capability of tosca.nodes.nfv.Vdu.Compute.
+ * ExtractInfofromVdu, supported hpa features, All under the capability of
+ * tosca.nodes.nfv.Vdu.Compute.
*
* @param lnodeVdu the list of Vdu node
*
@@ -146,7 +147,7 @@ public class ExtractFromNode {
final CapabilityAssignments capabilityAssignments = sdcCsarHelper.getCapabilitiesOf(node);
final CapabilityAssignment capabilityAssignment =
- capabilityAssignments.getCapabilityByName("virtual_compute");
+ capabilityAssignments.getCapabilityByName("virtual_compute");
if (capabilityAssignment != null) {
generateBasicCapability(capabilityAssignment, flavorFeature);
generateHugePages(capabilityAssignment, flavorFeature);
@@ -156,21 +157,22 @@ public class ExtractFromNode {
}
/**
- * GenerateBasicCapability, supported hpa features, All under the capability of tosca.nodes.nfv.Vdu.Compute.
+ * GenerateBasicCapability, supported hpa features, All under the capability of
+ * tosca.nodes.nfv.Vdu.Compute.
*
* @param capabilityAssignment represents the capability of node
*
* @param flavorFeature represents all the features of specified flavor
*/
private void generateBasicCapability(final CapabilityAssignment capabilityAssignment,
- final FlavorFeature flavorFeature) {
+ final FlavorFeature flavorFeature) {
// the format is xxx MB/GB like 4096 MB
final String virtualMemSize =
- sdcCsarHelper.getCapabilityPropertyLeafValue(capabilityAssignment, VIRTUAL_MEM_SIZE_PATH);
+ sdcCsarHelper.getCapabilityPropertyLeafValue(capabilityAssignment, VIRTUAL_MEM_SIZE_PATH);
if (virtualMemSize != null) {
LOGGER.debug("the virtualMemSize = {}", virtualMemSize);
final HpaFeatureAttribute hpaFeatureAttribute =
- generateHpaFeatureAttribute("virtualMemSize", virtualMemSize);
+ generateHpaFeatureAttribute("virtualMemSize", virtualMemSize);
final FlavorProperty flavorProperty = new FlavorProperty();
flavorProperty.setHpaFeature(BASIC_CAPABILITIES_HPA_FEATURE);
flavorProperty.getHpaFeatureAttributes().add(hpaFeatureAttribute);
@@ -179,12 +181,12 @@ public class ExtractFromNode {
// the format is int like 2
final String numVirtualCpu =
- sdcCsarHelper.getCapabilityPropertyLeafValue(capabilityAssignment, NUM_VIRTUAL_CPU_PATH);
+ sdcCsarHelper.getCapabilityPropertyLeafValue(capabilityAssignment, NUM_VIRTUAL_CPU_PATH);
if (numVirtualCpu != null) {
LOGGER.debug("the numVirtualCpu = {}", numVirtualCpu);
final HpaFeatureAttribute hpaFeatureAttribute = generateHpaFeatureAttribute("numVirtualCpu", numVirtualCpu);
final String cpuArchitecture =
- sdcCsarHelper.getCapabilityPropertyLeafValue(capabilityAssignment, CPU_ARCHITECTURE_PATH);
+ sdcCsarHelper.getCapabilityPropertyLeafValue(capabilityAssignment, CPU_ARCHITECTURE_PATH);
final FlavorProperty flavorProperty = new FlavorProperty();
flavorProperty.setHpaFeature(BASIC_CAPABILITIES_HPA_FEATURE);
if (cpuArchitecture != null) {
@@ -196,8 +198,9 @@ public class ExtractFromNode {
}
/**
- * GenerateHpaFeatureAttribute based on the value of featureValue. the format: "hpa-attribute-key": "pciVendorId",
- * "hpa-attribute-value": "1234", "operator": "=", "unit": "xxx".
+ * GenerateHpaFeatureAttribute based on the value of featureValue. the format:
+ * "hpa-attribute-key": "pciVendorId", "hpa-attribute-value": "1234", "operator": "=",
+ * "unit": "xxx".
*
* @param hpaAttributeKey get from the high layer tosca DM
*
@@ -227,8 +230,9 @@ public class ExtractFromNode {
}
/**
- * GenerateHugePages, supported hpa features, All under the capability of tosca.nodes.nfv.Vdu.Compute. The format is
- * a map like: {"schemaVersion": "0", "schemaSelector": "", "hardwarePlatform": "generic", "mandatory": "true",
+ * GenerateHugePages, supported hpa features, All under the capability of
+ * tosca.nodes.nfv.Vdu.Compute. The format is a map like: {"schemaVersion": "0",
+ * "schemaSelector": "", "hardwarePlatform": "generic", "mandatory": "true",
* "configurationValue": "2 MB"}
*
* @param capabilityAssignment represents the capability of node
@@ -237,11 +241,11 @@ public class ExtractFromNode {
*/
private void generateHugePages(final CapabilityAssignment capabilityAssignment, final FlavorFeature flavorFeature) {
final String memoryPageSize =
- sdcCsarHelper.getCapabilityPropertyLeafValue(capabilityAssignment, MEMORY_PAGE_SIZE_PATH);
+ sdcCsarHelper.getCapabilityPropertyLeafValue(capabilityAssignment, MEMORY_PAGE_SIZE_PATH);
LOGGER.debug("the memoryPageSize = {}", memoryPageSize);
if (memoryPageSize != null) {
final Map<String, String> retMap =
- gson.fromJson(memoryPageSize, new TypeToken<HashMap<String, String>>() {}.getType());
+ gson.fromJson(memoryPageSize, new TypeToken<HashMap<String, String>>() {}.getType());
LOGGER.debug("the retMap = {}", retMap);
final String memoryPageSizeValue = retMap.get(CONFIGURATION_VALUE);
final String mandatory = retMap.get("mandatory");
@@ -249,7 +253,7 @@ public class ExtractFromNode {
return;
}
final HpaFeatureAttribute hpaFeatureAttribute =
- generateHpaFeatureAttribute("memoryPageSize", memoryPageSizeValue);
+ generateHpaFeatureAttribute("memoryPageSize", memoryPageSizeValue);
final FlavorProperty flavorProperty = new FlavorProperty();
flavorProperty.setHpaFeature(HUGE_PAGES_HPA_FEATURE);
if (mandatory != null) {
@@ -261,8 +265,8 @@ public class ExtractFromNode {
}
/**
- * ExtractInfoVduCp, supported hpa features, under the virtual_network_interface_requirements of
- * tosca.nodes.nfv.VduCp.
+ * ExtractInfoVduCp, supported hpa features, under the
+ * virtual_network_interface_requirements of tosca.nodes.nfv.VduCp.
*
* @param lnodeVduCp the list of VduCp node
*
@@ -270,7 +274,7 @@ public class ExtractFromNode {
* @throws PolicyDecodingException if extract CP fails
*/
public void extractInfoVduCp(final List<NodeTemplate> lnodeVduCp, final Content content)
- throws PolicyDecodingException {
+ throws PolicyDecodingException {
// each CP will binds to a VDU so need the vdu flavor map info.
final Map<String, FlavorFeature> vduFlavorMap = new HashMap<>();
for (final FlavorFeature flavorFeature : content.getFlavorFeatures()) {
@@ -288,10 +292,10 @@ public class ExtractFromNode {
* @throws PolicyDecodingException if any error occurs
*/
private void parseNodeVduCp(final List<NodeTemplate> lnodeVduCp, final Map<String, FlavorFeature> vduFlavorMap)
- throws PolicyDecodingException {
+ throws PolicyDecodingException {
for (final NodeTemplate node : lnodeVduCp) {
final String interfaceType =
- sdcCsarHelper.getNodeTemplatePropertyLeafValue(node, NETWORK_INTERFACE_TYPE_PATH);
+ sdcCsarHelper.getNodeTemplatePropertyLeafValue(node, NETWORK_INTERFACE_TYPE_PATH);
LOGGER.debug("the interfaceType = {}", interfaceType);
Map<String, Object> retMap = new HashMap<>();
if (interfaceType != null) {
@@ -301,7 +305,7 @@ public class ExtractFromNode {
String networkHpaFeature;
if (retMap.containsKey(CONFIGURATION_VALUE)
- && NETWORK_HPA_FEATURE_MAP.containsKey(retMap.get(CONFIGURATION_VALUE).toString())) {
+ && NETWORK_HPA_FEATURE_MAP.containsKey(retMap.get(CONFIGURATION_VALUE).toString())) {
final String interfaceTypeValue = retMap.get(CONFIGURATION_VALUE).toString();
networkHpaFeature = NETWORK_HPA_FEATURE_MAP.get(interfaceTypeValue);
LOGGER.debug(" the networkHpaFeature is = {}", networkHpaFeature);
@@ -311,7 +315,7 @@ public class ExtractFromNode {
}
final RequirementAssignments requriements =
- sdcCsarHelper.getRequirementsOf(node).getRequirementsByName("virtual_binding");
+ sdcCsarHelper.getRequirementsOf(node).getRequirementsByName("virtual_binding");
for (final RequirementAssignment requriement : requriements.getAll()) {
final String nodeTemplateName = requriement.getNodeTemplateName();
LOGGER.debug("getNodeTemplateName = {}", nodeTemplateName);
@@ -327,19 +331,19 @@ public class ExtractFromNode {
}
/**
- * GenerateNetworkFeature, all pci feature are grouped into FlavorFeature together. The format is a map like:
- * {"schemaVersion": "0", "schemaSelector": "", "hardwarePlatform": "generic", "mandatory": "true",
- * "configurationValue": "2 MB"}
+ * GenerateNetworkFeature, all pci feature are grouped into FlavorFeature together.
+ * The format is a map like: {"schemaVersion": "0", "schemaSelector": "",
+ * "hardwarePlatform": "generic", "mandatory": "true", "configurationValue": "2 MB"}
*
* @param networkHpaFeature represents the specified Hpa feature
* @param node represents the CP Node
* @param flavorFeature represents all the features of specified flavor
*/
private void generateNetworkFeature(final String networkHpaFeature, final NodeTemplate node,
- final FlavorFeature flavorFeature) {
+ final FlavorFeature flavorFeature) {
final FlavorProperty flavorProperty = new FlavorProperty();
flavorProperty.setHpaFeature(networkHpaFeature);
- final String[] pciKeys = { "pciVendorId", "pciDeviceId", "pciNumDevices", "physicalNetwork" };
+ final String[] pciKeys = {"pciVendorId", "pciDeviceId", "pciNumDevices", "physicalNetwork"};
for (final String pciKey : pciKeys) {
LOGGER.debug("the pciKey = {}", pciKey);
final String pciKeyPath = NETWORK_PCI_PATH + "#" + pciKey;
@@ -347,7 +351,7 @@ public class ExtractFromNode {
if (pciValue != null) {
LOGGER.debug("the pciValue = {}", pciValue);
final Map<String, String> retMap =
- gson.fromJson(pciValue, new TypeToken<HashMap<String, String>>() {}.getType());
+ gson.fromJson(pciValue, new TypeToken<HashMap<String, String>>() {}.getType());
final String pciConfigValue = retMap.get(CONFIGURATION_VALUE);
if (pciConfigValue == null) {
return;
diff --git a/plugins/reception-plugins/src/main/java/org/onap/policy/distribution/reception/decoding/pdpx/FlavorFeature.java b/plugins/reception-plugins/src/main/java/org/onap/policy/distribution/reception/decoding/hpa/FlavorFeature.java
index c29378de..75643a72 100644
--- a/plugins/reception-plugins/src/main/java/org/onap/policy/distribution/reception/decoding/pdpx/FlavorFeature.java
+++ b/plugins/reception-plugins/src/main/java/org/onap/policy/distribution/reception/decoding/hpa/FlavorFeature.java
@@ -18,7 +18,7 @@
* ============LICENSE_END=========================================================
*/
-package org.onap.policy.distribution.reception.decoding.pdpx;
+package org.onap.policy.distribution.reception.decoding.hpa;
import java.util.ArrayList;
import java.util.List;
diff --git a/plugins/reception-plugins/src/main/java/org/onap/policy/distribution/reception/decoding/pdpx/FlavorProperty.java b/plugins/reception-plugins/src/main/java/org/onap/policy/distribution/reception/decoding/hpa/FlavorProperty.java
index 0453370d..f849ebaa 100644
--- a/plugins/reception-plugins/src/main/java/org/onap/policy/distribution/reception/decoding/pdpx/FlavorProperty.java
+++ b/plugins/reception-plugins/src/main/java/org/onap/policy/distribution/reception/decoding/hpa/FlavorProperty.java
@@ -18,7 +18,7 @@
* ============LICENSE_END=========================================================
*/
-package org.onap.policy.distribution.reception.decoding.pdpx;
+package org.onap.policy.distribution.reception.decoding.hpa;
import com.google.gson.annotations.SerializedName;
diff --git a/plugins/reception-plugins/src/main/java/org/onap/policy/distribution/reception/decoding/pdpx/HpaFeatureAttribute.java b/plugins/reception-plugins/src/main/java/org/onap/policy/distribution/reception/decoding/hpa/HpaFeatureAttribute.java
index 91008aa5..8bb078ad 100644
--- a/plugins/reception-plugins/src/main/java/org/onap/policy/distribution/reception/decoding/pdpx/HpaFeatureAttribute.java
+++ b/plugins/reception-plugins/src/main/java/org/onap/policy/distribution/reception/decoding/hpa/HpaFeatureAttribute.java
@@ -18,7 +18,7 @@
* ============LICENSE_END=========================================================
*/
-package org.onap.policy.distribution.reception.decoding.pdpx;
+package org.onap.policy.distribution.reception.decoding.hpa;
import com.google.gson.annotations.SerializedName;
diff --git a/plugins/reception-plugins/src/main/java/org/onap/policy/distribution/reception/decoding/pdpx/PolicyDecoderCsarPdpxLifecycleApi.java b/plugins/reception-plugins/src/main/java/org/onap/policy/distribution/reception/decoding/hpa/PolicyDecoderCsarHpa.java
index 8cfc6857..e1e1a9a9 100644
--- a/plugins/reception-plugins/src/main/java/org/onap/policy/distribution/reception/decoding/pdpx/PolicyDecoderCsarPdpxLifecycleApi.java
+++ b/plugins/reception-plugins/src/main/java/org/onap/policy/distribution/reception/decoding/hpa/PolicyDecoderCsarHpa.java
@@ -18,7 +18,7 @@
* ============LICENSE_END=========================================================
*/
-package org.onap.policy.distribution.reception.decoding.pdpx;
+package org.onap.policy.distribution.reception.decoding.hpa;
import java.io.File;
import java.util.ArrayList;
@@ -26,17 +26,12 @@ import java.util.Collection;
import java.util.LinkedHashMap;
import java.util.List;
import java.util.Map;
-
import org.onap.policy.common.parameters.ParameterService;
-import org.onap.policy.common.utils.coder.StandardCoder;
import org.onap.policy.distribution.model.Csar;
import org.onap.policy.distribution.model.PolicyInput;
import org.onap.policy.distribution.reception.decoding.PolicyDecoder;
import org.onap.policy.distribution.reception.decoding.PolicyDecodingException;
-import org.onap.policy.models.tosca.authorative.concepts.ToscaEntityKey;
import org.onap.policy.models.tosca.authorative.concepts.ToscaPolicy;
-import org.onap.policy.models.tosca.authorative.concepts.ToscaPolicyType;
-import org.onap.policy.models.tosca.authorative.concepts.ToscaProperty;
import org.onap.policy.models.tosca.authorative.concepts.ToscaServiceTemplate;
import org.onap.policy.models.tosca.authorative.concepts.ToscaTopologyTemplate;
import org.onap.sdc.tosca.parser.api.ISdcCsarHelper;
@@ -48,11 +43,10 @@ import org.slf4j.LoggerFactory;
/**
* Decodes PDP-X policies from a CSAR file and creates ToscaServiceTemplate for Policy Lifecycle API's.
*/
-public class PolicyDecoderCsarPdpxLifecycleApi implements PolicyDecoder<Csar, ToscaServiceTemplate> {
+public class PolicyDecoderCsarHpa implements PolicyDecoder<Csar, ToscaServiceTemplate> {
- private static final Logger LOGGER = LoggerFactory.getLogger(PolicyDecoderCsarPdpxLifecycleApi.class);
- private final StandardCoder coder = new StandardCoder();
- private PolicyDecoderCsarPdpxLifecycleApiParameters decoderParameters;
+ private static final Logger LOGGER = LoggerFactory.getLogger(PolicyDecoderCsarHpa.class);
+ private PolicyDecoderCsarHpaParameters decoderParameters;
public static final String TOSCA_POLICY_SCOPE = "scope";
public static final String TOSCA_POLICY_SERVICES = "services";
@@ -118,9 +112,7 @@ public class PolicyDecoderCsarPdpxLifecycleApi implements PolicyDecoder<Csar, To
final File csarFile = new File(csar.getCsarPath());
sdcCsarHelper = factory.getSdcCsarHelper(csarFile.getAbsolutePath());
} catch (final Exception exp) {
- final String message = "Failed passing the csar file";
- LOGGER.error(message, exp);
- throw new PolicyDecodingException(message, exp);
+ throw new PolicyDecodingException( "Failed passing the csar file", exp);
}
return sdcCsarHelper;
}
diff --git a/plugins/reception-plugins/src/main/java/org/onap/policy/distribution/reception/decoding/pdpx/ConfigBody.java b/plugins/reception-plugins/src/main/java/org/onap/policy/distribution/reception/decoding/pdpx/ConfigBody.java
deleted file mode 100644
index 521fcfd6..00000000
--- a/plugins/reception-plugins/src/main/java/org/onap/policy/distribution/reception/decoding/pdpx/ConfigBody.java
+++ /dev/null
@@ -1,115 +0,0 @@
-/*-
- * ============LICENSE_START=======================================================
- * Copyright (C) 2018 Ericsson. All rights reserved.
- * ================================================================================
- * Licensed under the Apache License, Version 2.0 (the "License");
- * you may not use this file except in compliance with the License.
- * You may obtain a copy of the License at
- *
- * http://www.apache.org/licenses/LICENSE-2.0
- *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
- *
- * SPDX-License-Identifier: Apache-2.0
- * ============LICENSE_END=========================================================
- */
-
-package org.onap.policy.distribution.reception.decoding.pdpx;
-
-public class ConfigBody {
-
- private String service;
- private String policyName;
- private String description;
- private String templateVersion;
- private String version;
- private String priority;
- private String riskType;
- private String riskLevel;
- private String guard;
- private Content content;
-
- public String getService() {
- return service;
- }
-
- public void setService(String service) {
- this.service = service;
- }
-
- public String getPolicyName() {
- return policyName;
- }
-
- public void setPolicyName(String policyName) {
- this.policyName = policyName;
- }
-
- public String getDescription() {
- return description;
- }
-
- public void setDescription(String description) {
- this.description = description;
- }
-
- public String getTemplateVersion() {
- return templateVersion;
- }
-
- public void setTemplateVersion(String templateVersion) {
- this.templateVersion = templateVersion;
- }
-
- public String getVersion() {
- return version;
- }
-
- public void setVersion(String version) {
- this.version = version;
- }
-
- public String getPriority() {
- return priority;
- }
-
- public void setPriority(String priority) {
- this.priority = priority;
- }
-
- public String getRiskType() {
- return riskType;
- }
-
- public void setRiskType(String riskType) {
- this.riskType = riskType;
- }
-
- public String getRiskLevel() {
- return riskLevel;
- }
-
- public void setRiskLevel(String riskLevel) {
- this.riskLevel = riskLevel;
- }
-
- public String getGuard() {
- return guard;
- }
-
- public void setGuard(String guard) {
- this.guard = guard;
- }
-
- public Content getContent() {
- return content;
- }
-
- public void setContent(Content content) {
- this.content = content;
- }
-}
diff --git a/plugins/reception-plugins/src/main/java/org/onap/policy/distribution/reception/decoding/pdpx/PdpxPolicy.java b/plugins/reception-plugins/src/main/java/org/onap/policy/distribution/reception/decoding/pdpx/PdpxPolicy.java
deleted file mode 100644
index e7a0e8ab..00000000
--- a/plugins/reception-plugins/src/main/java/org/onap/policy/distribution/reception/decoding/pdpx/PdpxPolicy.java
+++ /dev/null
@@ -1,127 +0,0 @@
-/*-
- * ============LICENSE_START=======================================================
- * Copyright (C) 2018 Ericsson. All rights reserved.
- * ================================================================================
- * Licensed under the Apache License, Version 2.0 (the "License");
- * you may not use this file except in compliance with the License.
- * You may obtain a copy of the License at
- *
- * http://www.apache.org/licenses/LICENSE-2.0
- *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
- *
- * SPDX-License-Identifier: Apache-2.0
- * ============LICENSE_END=========================================================
- */
-
-package org.onap.policy.distribution.reception.decoding.pdpx;
-
-import org.onap.policy.distribution.model.Policy;
-import org.onap.policy.distribution.reception.decoding.PolicyDecoder;
-
-/**
- * A PDP-X Policy, decoded by a {@link PolicyDecoder}.
- */
-public class PdpxPolicy implements Policy {
-
- private String guard;
- private String service;
- private String policyName;
- private String description;
- private String templateVersion;
- private String version;
- private String riskType;
- private String priority;
- private String riskLevel;
- private Content content = new Content();
-
- @Override
- public String getPolicyName() {
- return policyName;
- }
-
- @Override
- public String getPolicyType() {
- return content.getPolicyType();
- }
-
- public String getGuard() {
- return guard;
- }
-
- public String getService() {
- return service;
- }
-
- public String getDescription() {
- return description;
- }
-
- public String getTemplateVersion() {
- return templateVersion;
- }
-
- public String getVersion() {
- return version;
- }
-
- public String getRiskType() {
- return riskType;
- }
-
- public String getPriority() {
- return priority;
- }
-
- public String getRiskLevel() {
- return riskLevel;
- }
-
- public Content getContent() {
- return content;
- }
-
- public void setGuard(final String guard) {
- this.guard = guard;
- }
-
- public void setService(final String service) {
- this.service = service;
- }
-
- public void setPolicyName(final String policyName) {
- this.policyName = policyName;
- }
-
- public void setDescription(final String description) {
- this.description = description;
- }
-
- public void setTemplateVersion(final String templateVersion) {
- this.templateVersion = templateVersion;
- }
-
- public void setVersion(final String version) {
- this.version = version;
- }
-
- public void setRiskType(final String riskType) {
- this.riskType = riskType;
- }
-
- public void setPriority(final String priority) {
- this.priority = priority;
- }
-
- public void setRiskLevel(final String riskLevel) {
- this.riskLevel = riskLevel;
- }
-
- public void setContent(final Content content) {
- this.content = content;
- }
-}
diff --git a/plugins/reception-plugins/src/main/java/org/onap/policy/distribution/reception/decoding/pdpx/PolicyDecoderCsarPdpx.java b/plugins/reception-plugins/src/main/java/org/onap/policy/distribution/reception/decoding/pdpx/PolicyDecoderCsarPdpx.java
deleted file mode 100644
index 842245c0..00000000
--- a/plugins/reception-plugins/src/main/java/org/onap/policy/distribution/reception/decoding/pdpx/PolicyDecoderCsarPdpx.java
+++ /dev/null
@@ -1,122 +0,0 @@
-/*-
- * ============LICENSE_START=======================================================
- * Copyright (C) 2018 Ericsson. All rights reserved.
- * Copyright (C) 2019 Nordix Foundation.
- * ================================================================================
- * Licensed under the Apache License, Version 2.0 (the "License");
- * you may not use this file except in compliance with the License.
- * You may obtain a copy of the License at
- *
- * http://www.apache.org/licenses/LICENSE-2.0
- *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
- *
- * SPDX-License-Identifier: Apache-2.0
- * ============LICENSE_END=========================================================
- */
-
-package org.onap.policy.distribution.reception.decoding.pdpx;
-
-import com.google.gson.Gson;
-import com.google.gson.GsonBuilder;
-
-import java.io.File;
-import java.util.ArrayList;
-import java.util.Collection;
-import java.util.List;
-
-import org.onap.policy.common.parameters.ParameterService;
-import org.onap.policy.distribution.model.Csar;
-import org.onap.policy.distribution.model.OptimizationPolicy;
-import org.onap.policy.distribution.model.PolicyInput;
-import org.onap.policy.distribution.reception.decoding.PolicyDecoder;
-import org.onap.policy.distribution.reception.decoding.PolicyDecodingException;
-import org.onap.sdc.tosca.parser.api.ISdcCsarHelper;
-import org.onap.sdc.tosca.parser.impl.SdcToscaParserFactory;
-import org.onap.sdc.toscaparser.api.NodeTemplate;
-import org.slf4j.Logger;
-import org.slf4j.LoggerFactory;
-
-/**
- * Decodes PDP-X policies from a CSAR file.
- */
-public class PolicyDecoderCsarPdpx implements PolicyDecoder<Csar, OptimizationPolicy> {
-
- private static final Logger LOGGER = LoggerFactory.getLogger(PolicyDecoderCsarPdpx.class);
- private final Gson gson = new GsonBuilder().serializeNulls().disableHtmlEscaping().create();
- private PolicyDecoderCsarPdpxConfigurationParameterGroup decoderParameters;
-
- @Override
- public Collection<OptimizationPolicy> decode(final Csar csar) throws PolicyDecodingException {
- final List<OptimizationPolicy> policies = new ArrayList<>();
- final ISdcCsarHelper sdcCsarHelper = parseCsar(csar);
- final List<NodeTemplate> lnodeVf = sdcCsarHelper.getServiceVfList();
- LOGGER.debug("the size of Vf = {}", lnodeVf.size());
- final ExtractFromNode extractFromNode = new ExtractFromNode();
- extractFromNode.setSdcCsarHelper(sdcCsarHelper);
- final String serviceName = sdcCsarHelper.getServiceMetadata().getValue("name");
- LOGGER.debug("the name of the service = {}", serviceName);
- for (final NodeTemplate node : lnodeVf) {
- final Content content = extractFromNode.extractInfo(node);
- if (content != null) {
- final OptimizationPolicy policy = new OptimizationPolicy();
- final String policyName = decoderParameters.getPolicyNamePrefix() + "." + content.getIdentity();
- policy.setOnapName(decoderParameters.getOnapName());
- policy.setName(policyName);
- final ConfigBody configBody = new ConfigBody();
- configBody.setService("hpaPolicy");
- configBody.setPolicyName(policyName);
- configBody.setDescription("OOF Policy");
- configBody.setTemplateVersion("OpenSource.version.1");
- configBody.setVersion(decoderParameters.getVersion());
- configBody.setPriority(decoderParameters.getPriority());
- configBody.setRiskLevel(decoderParameters.getRiskLevel());
- configBody.setRiskType(decoderParameters.getRiskType());
- configBody.setGuard("False");
- content.setPolicyType("hpa");
- content.getPolicyScope().add("HPA");
- content.getPolicyScope().add(serviceName);
- configBody.setContent(content);
- policy.setConfigBody(gson.toJson(configBody));
- policies.add(policy);
- }
- }
- return policies;
- }
-
- @Override
- public boolean canHandle(final PolicyInput policyInput) {
- return policyInput.getClass().isAssignableFrom(Csar.class);
- }
-
- /**
- * Parse the input Csar using SDC TOSCA parser.
- *
- * @param csar represents the service TOSCA Csar
- * @return the object to represents the content of input csar
- * @throws PolicyDecodingException if parse fails
- */
- public ISdcCsarHelper parseCsar(final Csar csar) throws PolicyDecodingException {
- ISdcCsarHelper sdcCsarHelper;
- try {
- final SdcToscaParserFactory factory = SdcToscaParserFactory.getInstance();
- LOGGER.debug("Csar File Path = {}", csar.getCsarPath());
- final File csarFile = new File(csar.getCsarPath());
- sdcCsarHelper = factory.getSdcCsarHelper(csarFile.getAbsolutePath());
- } catch (final Exception exp) {
- final String message = "Failed passing the csar file";
- LOGGER.error(message, exp);
- throw new PolicyDecodingException(message, exp);
- }
- return sdcCsarHelper;
- }
-
- @Override
- public void configure(final String parameterGroupName) {
- decoderParameters = ParameterService.get(parameterGroupName);
- }
-}
diff --git a/plugins/reception-plugins/src/main/java/org/onap/policy/distribution/reception/decoding/pdpx/PolicyDecoderCsarPdpxConfigurationParameterGroup.java b/plugins/reception-plugins/src/main/java/org/onap/policy/distribution/reception/decoding/pdpx/PolicyDecoderCsarPdpxConfigurationParameterGroup.java
deleted file mode 100644
index f376c391..00000000
--- a/plugins/reception-plugins/src/main/java/org/onap/policy/distribution/reception/decoding/pdpx/PolicyDecoderCsarPdpxConfigurationParameterGroup.java
+++ /dev/null
@@ -1,49 +0,0 @@
-/*-
- * ============LICENSE_START=======================================================
- * Copyright (C) 2018 Intel. All rights reserved.
- * Modifications Copyright (C) 2019 Nordix Foundation.
- * ================================================================================
- * Licensed under the Apache License, Version 2.0 (the "License");
- * you may not use this file except in compliance with the License.
- * You may obtain a copy of the License at
- *
- * http://www.apache.org/licenses/LICENSE-2.0
- *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
- *
- * SPDX-License-Identifier: Apache-2.0
- * ============LICENSE_END=========================================================
- */
-
-package org.onap.policy.distribution.reception.decoding.pdpx;
-
-import lombok.Getter;
-
-import org.onap.policy.common.parameters.annotations.NotBlank;
-import org.onap.policy.common.parameters.annotations.NotNull;
-import org.onap.policy.distribution.reception.parameters.PolicyDecoderConfigurationParameterGroup;
-
-/**
- * This class handles reading, parsing and validating of the paramaters for the {@link PolicyDecoderCsarPdpx}.
- */
-@Getter
-@NotNull
-@NotBlank
-public class PolicyDecoderCsarPdpxConfigurationParameterGroup extends PolicyDecoderConfigurationParameterGroup {
-
- private String policyNamePrefix;
- private String onapName;
- private String version;
- private String priority;
- private String riskType;
- private String riskLevel;
-
- public PolicyDecoderCsarPdpxConfigurationParameterGroup() {
- super(PolicyDecoderCsarPdpxConfigurationParameterGroup.class.getSimpleName());
- }
-}
-
diff --git a/plugins/reception-plugins/src/main/java/org/onap/policy/distribution/reception/decoding/pdpx/PolicyDecoderCsarPdpxLifecycleApiParameters.java b/plugins/reception-plugins/src/main/java/org/onap/policy/distribution/reception/decoding/hpa/PolicyDecoderCsarHpaParameters.java
index a66a53a8..7d26335c 100644
--- a/plugins/reception-plugins/src/main/java/org/onap/policy/distribution/reception/decoding/pdpx/PolicyDecoderCsarPdpxLifecycleApiParameters.java
+++ b/plugins/reception-plugins/src/main/java/org/onap/policy/distribution/reception/decoding/hpa/PolicyDecoderCsarHpaParameters.java
@@ -19,7 +19,7 @@
* ============LICENSE_END=========================================================
*/
-package org.onap.policy.distribution.reception.decoding.pdpx;
+package org.onap.policy.distribution.reception.decoding.hpa;
import lombok.Getter;
@@ -28,12 +28,12 @@ import org.onap.policy.common.parameters.annotations.NotNull;
import org.onap.policy.distribution.reception.parameters.PolicyDecoderConfigurationParameterGroup;
/**
* This class handles the parameters needed for {@link PolicyDecoderCsarPdpxLifecycleApi}.
*/
@Getter
@NotNull
@NotBlank
-public class PolicyDecoderCsarPdpxLifecycleApiParameters extends PolicyDecoderConfigurationParameterGroup {
+public class PolicyDecoderCsarHpaParameters extends PolicyDecoderConfigurationParameterGroup {
private String policyNamePrefix;
private String onapName;
@@ -42,8 +42,8 @@ public class PolicyDecoderCsarPdpxLifecycleApiParameters extends PolicyDecoderCo
private String riskType;
private String riskLevel;
- public PolicyDecoderCsarPdpxLifecycleApiParameters() {
- super(PolicyDecoderCsarPdpxLifecycleApiParameters.class.getSimpleName());
+ public PolicyDecoderCsarHpaParameters() {
+ super(PolicyDecoderCsarHpaParameters.class.getSimpleName());
}
}
@@ -28,12 +28,12 @@ import org.onap.policy.common.parameters.annotations.NotNull;
import org.onap.policy.distribution.reception.parameters.PolicyDecoderConfigurationParameterGroup;
/**
- * This class handles the parameters needed for {@link PolicyDecoderCsarPdpxLifecycleApi}.
+ * This class handles the parameters needed for {@link PolicyDecoderCsarHpa}.
*/